import { Handle, HandleType, Position } from 'reactflow';
import { QueryGraphEdgeHandle } from '../../..';
import { tailwindColors } from 'config';
import { FilterHandle } from '../../FilterHandle';

const rightArrow = '0,0 8,5 0,10';
const leftArrow = '8,0 0,5 8,10';
const square = '9,9 1,9 1,1 9,1';
const getArrow = {
  right: rightArrow,
  left: leftArrow,
  both: square,
};
export type RelationshipHandleArrowType = 'right' | 'left' | 'both';

type Props = {
  handle: QueryGraphEdgeHandle;
  type: HandleType;
  point: RelationshipHandleArrowType;
  onDoubleClick?: () => void;
};

export const LeftHandle = (props: Props) => {
  return (
    <FilterHandle
      handle={props.handle}
      type={props.type}
      position={Position.Left}
      onDoubleClickCapture={(e) => {
        e.preventDefault();
        e.stopPropagation();
        if (props.onDoubleClick) props.onDoubleClick();
      }}
    >
      <svg className="pointer-events-none" height={10} style={{ transform: `translate(3px, 4px)` }}>
        <polygon points={getArrow[props.point]} className="fill-primary-600" />
      </svg>
    </FilterHandle>
  );
};

export const RightHandle = (props: Props) => {
  return (
    <FilterHandle
      handle={props.handle}
      type={props.type}
      position={Position.Right}
      onDoubleClickCapture={(e) => {
        e.preventDefault();
        e.stopPropagation();
        if (props.onDoubleClick) props.onDoubleClick();
      }}
    >
      <svg height={10} className="pointer-events-none" style={{ transform: `translate(6px, 4px)` }}>
        <polygon points={getArrow[props.point]} className="fill-primary-600" />
      </svg>
    </FilterHandle>
  );
};
