import React from 'react';
import { Close, ExpandLess, ExpandMore, PlayArrow } from '@mui/icons-material';
import { GraphType } from '../types';

type Props = {
  graph: GraphType;
  setShowFilter: React.Dispatch<React.SetStateAction<boolean>>;
};

const minDistance = 10;

export default function FilterMenu({ graph, setShowFilter }: Props) {
  const [range, setRange] = React.useState<number>(20);
  const [expanded, setExpanded] = React.useState<boolean>(true);
  const [filterBy, setFilterBy] = React.useState<string>('');
  const [playing, setPlaying] = React.useState<boolean>(false);

  const edgeAttributes = graph.getGraphInfo().edgeAttributes;

  return (
    <div className="absolute z-10 bg-light w-11/12 bottom-5 p-2.5 left-2/4 -translate-x-1/2 shadow-sm">
      <div className="flex justify-between items-center">
        <div>
          <PlayArrow />
        </div>
        <h5>Selected attribute</h5>
        <div className="flex">
          <div onClick={() => setExpanded(!expanded)}>{expanded ? <ExpandMore /> : <ExpandLess />}</div>
          <div onClick={() => setShowFilter(false)}>
            <Close />
          </div>
        </div>
      </div>
      {expanded && (
        <>
          <div className="divider"></div>

          <div className="flex p-2 w-full">
            <div className="basis-1/3 flex flex-col w-full">
              <select className="select select-bordered w-full max-w-xs" value={filterBy} onChange={(e) => setFilterBy(e.target.value)}>
                <option disabled selected>
                  Attribute
                </option>
                {Object.keys(edgeAttributes).map((attribute) => (
                  <option key={attribute} value={attribute}>
                    {attribute}
                  </option>
                ))}
              </select>
            </div>
            <div className="basis-2/3 flex px-2 items-center">
              <input
                className="range"
                type="range"
                min={0}
                max={100}
                step={1}
                value={range}
                onChange={(e) => setRange(parseInt(e.target.value) || 0)}
              />
            </div>
          </div>
        </>
      )}
    </div>
  );
}
